@@ -12,9 +12,8 @@ namespace Quotient {
  *
  * *Note that there are two forms of this API, which are documented separately.
  * This version of the API requires that the inviter knows the Matrix
- * identifier of the invitee. The other is documented in the*
- * [third party invites
- * section](/client-server-api/#post_matrixclientr0roomsroomidinvite-1).
+ * identifier of the invitee. The other is documented in the
+ * [third party invites](/client-server-api/#third-party-invites) section.*
  *
  * This API invites a user to participate in a particular room.
  * They do not start participating in the room until they actually join the
@@ -26,7 +25,7 @@ namespace Quotient {
  * If the user was invited to the room, the homeserver will append a
  * `m.room.member` event to the room.
  */
-class InviteUserJob : public BaseJob {
+class QUOTIENT_API InviteUserJob : public BaseJob {
 public:
     /*! \brief Invite a user to participate in a particular room.
      *
@@ -35,8 +34,13 @@ public:
      *
      * \param userId
      *   The fully qualified user ID of the invitee.
+     *
+     * \param reason
+     *   Optional reason to be included as the `reason` on the subsequent
+     *   membership event.
      */
-    explicit InviteUserJob(const QString& roomId, const QString& userId);
+    explicit InviteUserJob(const QString& roomId, const QString& userId,
+                           const QString& reason = {});
 };
 
 } // namespace Quotient
