@@ -14,14 +14,14 @@ namespace Quotient {
  *
  * Gets discovery information about the domain. The file may include
  * additional keys, which MUST follow the Java package naming convention,
- * e.g. ``com.example.myapp.property``. This ensures property names are
+ * e.g. `com.example.myapp.property`. This ensures property names are
  * suitably namespaced for each application and reduces the risk of
  * clashes.
  *
  * Note that this endpoint is not necessarily handled by the homeserver,
  * but by another webserver, to be used for discovering the homeserver URL.
  */
-class GetWellknownJob : public BaseJob {
+class QUOTIENT_API GetWellknownJob : public BaseJob {
 public:
     /// Gets Matrix server discovery information about the domain.
     explicit GetWellknownJob();
